# -*- coding: utf-8 -*-
from setuphelpers import *
import pythoncom
import time

# Defining variables
task_name = "WAPTupgradeOnBoot"


def install():
    # Creating the scheduled task
    if task_exists(task_name):
        delete_task(task_name)
    try:
        create_onboot_task(task_name, "wapt-get", "upgrade -S --only_if_not_process_running=1")
        print("Creating the scheduled task: %s" % task_name)
    except:
        print("Unable to create the scheduled task: %s" % task_name)


def uninstall():
    # Removing the scheduled task
    if task_exists(task_name):
        try:
            delete_task(task_name)
        except:
            print("Unable to disable the scheduled task: %s" % task_name)


def audit():
    if not task_exists(task_name):
        print("task %s don't exist, WAPT is installing package to fix that" % task_name)
        install()
        return "WARNING"
    if not enable_task(task_name):
        print("task %s is disable, WAPT is going to enable the task" % task_name)
        enable_task(task_name)
        return "WARNING"
    else:
        print("task %s exist and is active" % task_name)
        return "OK"


def create_onboot_task(name, cmd, parameters, max_runtime=10):
    """creates a Windows scheduled task on boot and activate it.

    Args:
        name (str): name of task for reference
        cmd(str) :  command line
        parameters (str) : arguments to append to cmd
        max_runtime (int): maximum running time in minutes

    Returns:
        PyITask: scheduled task
    """
    ts = pythoncom.CoCreateInstance(taskscheduler.CLSID_CTaskScheduler, None, pythoncom.CLSCTX_INPROC_SERVER, taskscheduler.IID_ITaskScheduler)

    if "%s.job" % name not in ts.Enum():
        task = ts.NewWorkItem(name)

        task.SetApplicationName(cmd)
        task.SetParameters(parameters)
        task.SetAccountInformation("", None)
        if max_runtime:
            task.SetMaxRunTime(max_runtime * 60 * 1000)
        # task.SetFlags(task.GetFlags() | taskscheduler.TASK_FLAG_)
        ts.AddWorkItem(name, task)
        run_time = time.localtime(time.time() + 300)
        tr_ind, tr = task.CreateTrigger()
        tt = tr.GetTrigger()
        tt.Flags = 0
        tt.BeginYear = int(time.strftime("%Y", run_time))
        tt.BeginMonth = int(time.strftime("%m", run_time))
        tt.BeginDay = int(time.strftime("%d", run_time))
        tt.TriggerType = int(taskscheduler.TASK_EVENT_TRIGGER_AT_SYSTEMSTART)
        tr.SetTrigger(tt)
        pf = task.QueryInterface(pythoncom.IID_IPersistFile)
        pf.Save(None, 1)
        # task.Run()
    else:
        raise KeyError("%s already exists" % name)

    task = ts.Activate(name)
    # exit_code, startup_error_code = task.GetExitCode()
    return task
